=======
Authors
=======

Maintainers and core contributors are listed below in alphabetical order.

Maintainers
-----------
`Matthew R. Carbone <https://www.bnl.gov/staff/mcarbone>`_ [#f1]_ & Fanchen Meng [#f2]_

Core contributors
-----------------

Deyu Lu [#f2]_, Benedikt Maurer [#f3]_, Fabian Peschel [#f3]_, Eli Stavitski [#f4]_, Xiaohui Qu [#f2]_, John T. Vinson [#f5]_ & Christian Vorwerk [#f6]_

----

.. [#f1] Computational Science Initiative, Brookhaven National Laboratory, Upton, New York 11973, United States
.. [#f2] Center for Functional Nanomaterials, Brookhaven National Laboratory, Upton, New York 11973, United States
.. [#f3] Physics Department and IRIS Adlershof, Humboldt-Universitaet zu Berlin, D-12489 Berlin, Germany
.. [#f4] National Synchrotron Light Source II, Brookhaven National Laboratory, Upton, New York 11973, United States
.. [#f5] Material Measurement Laboratory, National Institute of Standards and Technology, Gaithersburg, Maryland 20899, United States
.. [#f6] Pritzker School of Molecular Engineering, University of Chicago, Chicago, IL 60637, United States
